﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.DataImporter.Data.Command {
  [StorableClass]
  public class RenameColumnCommand : ColumnCommandBase {
    [Storable]
    private string newName;

    private string oldName;

    [StorableConstructor]
    protected RenameColumnCommand(bool deserializing) : base(deserializing) { }

    public RenameColumnCommand(DataSet dataSet, string columnGroupName, int columnIndex, string newName)
      : base(dataSet, columnGroupName, columnIndex) {
      this.newName = newName;
    }

    public override string Description {
      get { return "Rename Column"; }
    }

    public override void Execute() {
      base.Execute();
      oldName = Column.Name;
      Column.Name = newName;
      Column.FireChanged();
      this.ColumnGroup = null;
    }

    public override void UndoExecute() {
      base.UndoExecute();
      Column.Name = oldName;
      oldName = null;
      Column.FireChanged();
      this.ColumnGroup = null;
    }
  }
}
